@@ -18,7 +18,7 @@ from urllib.parse import urlparse
 from bs4 import BeautifulSoup
 import requests
 
-from constants import TIMEOUT
+from .constants import TIMEOUT
 
 
 class XmlParser(object):
@@ -135,7 +135,10 @@ class ResourceLinkToText(XmlParser, SearchResultToText):
             response = self._get_text(url)
 
             if self._is_valid(response):
-                text = self._parse_text(response)
+                if url.endswith('.txt'):
+                    text = response.text
+                else:
+                    text = self._parse_text(response)
                 break
 
         return text
